API Reference
=============

This section provides detailed API documentation for the ndx-hed extension.

Core Classes
------------

HedLabMetaData
~~~~~~~~~~~~~~

.. autoclass:: ndx_hed.HedLabMetaData
   :members:
   :undoc-members:
   :show-inheritance:
   :special-members: __init__

HedTags
~~~~~~~

.. autoclass:: ndx_hed.HedTags
   :members:
   :undoc-members:
   :show-inheritance:
   :special-members: __init__

HedValueVector
~~~~~~~~~~~~~~

.. autoclass:: ndx_hed.HedValueVector
   :members:
   :undoc-members:
   :show-inheritance:
   :special-members: __init__

Validation Utilities
--------------------

HedNWBValidator
~~~~~~~~~~~~~~~

.. autoclass:: ndx_hed.utils.hed_nwb_validator.HedNWBValidator
   :members:
   :undoc-members:
   :show-inheritance:
   :special-members: __init__

BIDS Conversion Utilities
--------------------------

These utilities support bidirectional conversion between BIDS events and NWB EventsTable format.

.. automodule:: ndx_hed.utils.bids2nwb
   :members:
   :undoc-members:
   :show-inheritance:
